<#ibizinclude>
../../@MACRO/LANG_FUN.ftl
</#ibizinclude>
<template>
  <gantt-elastic :class="ganttClass" :tasks="tasks" :options="getOptions(this.locale)" :dynamic-style="dynamicStyle">
    <gantt-elastic-header :options="options" slot="header"></gantt-elastic-header>
  </gantt-elastic>
</template>
<#assign import_block>
import GanttElastic from "ibiz-gantt-elastic/src/GanttElastic.vue";
import ganttElasticHeader from "gantt-elastic-header/src/Header.vue";
</#assign>

<#assign component_block>
GanttElastic,
ganttElasticHeader,
</#assign>

<#ibizinclude>
../@MACRO/CONTROL/CONTROL_HEADER-BASE.vue.ftl
</#ibizinclude>

    /**
     * 显示处理提示
     *
     * @type {boolean}
     * @memberof ${srfclassname('${ctrl.codeName}')}
     */
    @Prop({ default: true }) public showBusyIndicator?: boolean;

    /**
     * 部件行为--load
     *
     * @type {string}
     * @memberof ${srfclassname('${ctrl.codeName}')}
     */
    @Prop() public loadAction!: string;

    /**
     * 部件样式名
     *
     * @public
     * @type {any[]}
     * @memberof ${srfclassname('${ctrl.codeName}')}
     */
    public ganttClass: string = "gantt";

     /**
     * 语言
     *
     * @public
     * @type {string}
     * @memberof ${srfclassname('${ctrl.codeName}')}
     */  
    public locale: string = 'zh-CN';

     /**
     * 语言资源
     *
     * @public
     * @type {any[]}
     * @memberof ${srfclassname('${ctrl.codeName}')}
     */   
    public localeZH: any =  {
        weekdays: ['星期一','星期二','星期三','星期四','星期五','星期六','星期日'],
        months: ['一月', '二月', '三月', '四月', '五月', '六月', '七月', '八月', '九月', '十月', '十一月', '十二月']
    }

    /**
     * 配置参数
     *
     * @public
     * @type {any[]}
     * @memberof ${srfclassname('${ctrl.codeName}')}
     */
    public options: any = {
        isflex: true,
        maxRows: 100,
        title: {
            label: "aaa",
            html: true
        },
        calendar: {
            hour: {
                display: false
            }
        },
        chart: {
            progress: {
                bar: false
            },
            expander: {
                display: true
            },
        },
        taskList: {
            expander: {
                straight: false
            },
            columns: [
                {
                    label: '名称',
                    value: 'label',
                    width: 150
                }
            ]
        }
    };

    /**
     * 样式
     *
     * @public
     * @type {any[]}
     * @memberof ${srfclassname('${ctrl.codeName}')}
     */
    public dynamicStyle: any = {

    };

    /**
     * 日程事件集合
     *
     * @public
     * @type {any[]}
     * @memberof ${srfclassname('${ctrl.codeName}')}
     */
    public tasks: any[] = [];

    /**
     * 日历样式类型
     *
     * @public
     * @type {string}
     * @memberof ${srfclassname('${ctrl.codeName}')}
     */
    public ganttType: string = "${ctrl.getGanttStyle()}";

    /**
     * 监听语言变化
     *
     * @public
     * @memberof ${srfclassname('${ctrl.codeName}')}
     */
    @Watch('$i18n.locale')
    public onLocaleChange(newval: any, val: any) {
        this.locale = newval;
    }

    /**
     * 获取部件参数
     *
     * @returns {any}
     * @memberof ${srfclassname('${ctrl.codeName}')}
     */
    public getOptions() {
        if(Object.is(this.locale, 'zh-CN')) {
            return { locale: this.localeZH, ...this.options };
        }
        return this.options;
    }

    /**
     * 搜索获取日程事件
     *
     * @param {*} $event 日期信息
     * @memberof ${srfclassname('${ctrl.codeName}')}
     */
    public searchEvents(fetchInfo?:any, successCallback?:any, failureCallback?:any ) {
        let start = (fetchInfo && fetchInfo.start) ? this.$util.dateFormat(fetchInfo.start) : null;
        let end = (fetchInfo && fetchInfo.end) ? this.$util.dateFormat(fetchInfo.end) : null;
        let arg = { start: start, end: end };
        if(fetchInfo && fetchInfo.query){
            Object.assign(arg,{query : fetchInfo.query});
        }
        Object.assign(arg,{viewparams:this.viewparams});
        const post: Promise<any> = this.service.search(this.loadAction, JSON.parse(JSON.stringify(this.context)), arg, this.showBusyIndicator);
        post.then((response: any) => {
            if (!response || response.status !== 200) {
                if (response.errorMessage) {
                    this.$Notice.error({ title: '错误', desc: response.errorMessage });
                }
                return;
            }
            // 默认选中第一项
            this.tasks = response.data;
        }, (response: any) => {
            if (response && response.status === 401) {
                return;
            }
            this.$Notice.error({ title: '错误', desc: response.errorMessage });
        });
    }

    /**
     * 获取编辑视图信息
     *
     * @param {*} $event 事件信息
     * @memberof ${srfclassname('${ctrl.codeName}')}
     */
    public getEditView(deName: string) {
        let view: any = {};
        switch(deName){
<#if view.getAllRelatedPSAppViews?? && view.getAllRelatedPSAppViews()??>
  <#list view.getAllRelatedPSAppViews() as editview>
            case "${editview.getPSDataEntity().getCodeName()?lower_case}": 
                view = {
                    viewname: '${srffilepath2(editview.getCodeName())}', 
                    height: ${editview.getHeight()?c}, 
                    width: ${editview.getWidth()?c},
                    title: this.<@getViewLanguageTitle editview />,
                    placement: '${editview.getOpenMode()}',
                    deResParameters: <#rt>
    <#if editview.isPSDEView()>
      [<#t>
      <#if editview.getPSAppDERSPathCount() gt 0>
        <#list editview.getPSAppDERSPath(editview.getPSAppDERSPathCount() - 1) as deRSPath>
        <#assign majorPSAppDataEntity = deRSPath.getMajorPSAppDataEntity()/><#t>
          { pathName: '${srfpluralize(majorPSAppDataEntity.codeName)?lower_case}', parameterName: '${majorPSAppDataEntity.getCodeName()?lower_case}' }, <#t>
        </#list>
      </#if>
      ],<#lt>
    <#else>
      [],<#lt>
    </#if>
                    parameters: <#rt>
    [<#t>
    <#if editview.isPSDEView()>
      <#assign appDataEntity = editview.getPSAppDataEntity()/>
      { pathName: '${srfpluralize(appDataEntity.codeName)?lower_case}', parameterName: '${appDataEntity.getCodeName()?lower_case}' }, <#t>
      { pathName: '${editview.getPSDEViewCodeName()?lower_case}', parameterName: '${editview.getPSDEViewCodeName()?lower_case}' } <#t>
    <#else>
      { pathName: '${editview.getCodeName()?lower_case}', parameterName: '${editview.getCodeName()?lower_case}' } <#t>
    </#if>
    ],<#lt>
                };
                break;
  </#list>
</#if>
        }
        return view;
    }

    /**
     * 点击事件
     *
     * @param {*} $event calendar事件对象或event数据
     * @param {*} isOriginData true：$event是原始event数据，false：是组件
     * @param {*} $event timeline事件对象
     * @memberof ${srfclassname('${ctrl.codeName}')}
     */
    public onEventClick($event: any, isOriginData:boolean = false, $event2?: any) {

    }

    /**
     * 刷新
     *
     * @memberof ${srfclassname('${ctrl.codeName}')}
     */
    public refresh() {
        this.searchEvents();
    }



    /**
     * 选中的数据
     *
     * @returns {any[]}
     * @memberof ${srfclassname('${ctrl.codeName}')}
     */
    public selections: any[] = [];

    /**
     * 获取多项数据
     *
     * @returns {any[]}
     * @memberof ${srfclassname('${ctrl.codeName}')}
     */
    public getDatas(): any[] {
        return this.selections;
    }

    /**
     * 获取单项树
     *
     * @returns {*}
     * @memberof ${srfclassname('${ctrl.codeName}')}
     */
    public getData(): any {
        return null;
    }
             
    /**
     * vue 生命周期
     *
     * @returns
     * @memberof ${srfclassname('${ctrl.codeName}')}
     */
    public created() {
        this.locale = this.$i18n.locale;
        this.searchEvents();
    }

<#ibizinclude>
../@MACRO/CONTROL/CONTROL_BOTTOM-BASE.vue.ftl
</#ibizinclude>

<#ibizinclude>
../@MACRO/CONTROL/CONTROL-BASE.style.ftl
</#ibizinclude>